% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/summarize_simulation_study.R
\name{summarize_simulation_study}
\alias{summarize_simulation_study}
\title{Summarize simulation or real-data study results}
\usage{
summarize_simulation_study(results)
}
\arguments{
\item{results}{A results data frame returned by \code{\link[=run_simulation_study]{run_simulation_study()}} or
\code{\link[=run_real_data_study]{run_real_data_study()}}.}
}
\value{
A grouped summary data frame.
}
\description{
Summarize simulation or real-data study results
}
\examples{
sim_results <- run_simulation_study(
  dimensions = list(c(30, 12)),
  true_ncomp = 2,
  missing_props = numeric(0),
  mechanisms = character(0),
  reps = 2,
  seed = 1
)
summarize_simulation_study(sim_results)
}
