% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/datasets.R
\docType{data}
\name{bromhexine}
\alias{bromhexine}
\title{Bromhexine dataset}
\format{
A \code{misspls_dataset} list with components:
\describe{
\item{name}{Dataset name.}
\item{x}{A numeric \verb{23 x 64} predictor matrix.}
\item{y}{A numeric response vector of length \code{23}.}
\item{data}{A data frame with response \code{y} and predictors \code{x1} to \code{x64}.}
\item{source}{A short source reference.}
\item{preprocessing}{Dataset preprocessing notes.}
\item{notes}{Additional study notes.}
}
}
\source{
Goicoechea and Olivieri (1999a), calibration and test files bundled in
\code{extra_docs/pls_data}.
}
\usage{
bromhexine
}
\description{
Bromhexine in pharmaceutical syrup used in the article and thesis.
}
\keyword{datasets}
